==> ips.commons-2.27.0-sources.jar: ipsk/swing/action/tree/CheckActionLeaf.java <==
//    IPS Java Utils
// 	  (c) Copyright 2011
// 	  Institute of Phonetics and Speech Processing,
//    Ludwig-Maximilians-University, Munich, Germany
//
//
//    This file is part of IPS Java Utils
//
//
//    IPS Java Utils is free software: you can redistribute it and/or modify
//    it under the terms of the GNU Lesser General Public License as published by
//    the Free Software Foundation, version 3 of the License.
//
//    IPS Java Utils is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU Lesser General Public License for more details.
//
//    You should have received a copy of the GNU Lesser General Public License
//    along with IPS Java Utils.  If not, see <http://www.gnu.org/licenses/>.

package ipsk.swing.action.tree;

import ipsk.util.LocalizableMessage;

import java.awt.ItemSelectable;
import java.awt.event.ActionEvent;

import javax.swing.Action;

/**
 * @author klausj
 *
 */
public abstract class CheckActionLeaf extends AbstractActionLeaf {

    /**
     * @param displayName
     */
    public CheckActionLeaf(LocalizableMessage displayName) {
        super(displayName);
        setSelected(true);
    }

    /* (non-Javadoc)
     * @see ips.incubator.awt.action.ActionLeaf#actionPerformed(java.awt.event.ActionEvent)
     */
    @Override
    public abstract void actionPerformed(ActionEvent arg0);

    public boolean isSelected() {
        Object selObj=getValue(Action.SELECTED_KEY);
        if(selObj!=null){
            if(selObj.equals(true)){
                return true;
            }
        }
        return false;
    }

    public void setSelected(boolean selected) {
        putValue(Action.SELECTED_KEY, selected);
    }

}

==> ips.commons-3.10.0-sources.jar: ipsk/swing/action/tree/CheckActionLeaf.java <==
//    IPS Java Utils
// 	  (c) Copyright 2011
// 	  Institute of Phonetics and Speech Processing,
//    Ludwig-Maximilians-University, Munich, Germany
//
//
//    This file is part of IPS Java Utils
//
//
//    IPS Java Utils is free software: you can redistribute it and/or modify
//    it under the terms of the GNU Lesser General Public License as published by
//    the Free Software Foundation, version 3 of the License.
//
//    IPS Java Utils is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU Lesser General Public License for more details.
//
//    You should have received a copy of the GNU Lesser General Public License
//    along with IPS Java Utils.  If not, see <http://www.gnu.org/licenses/>.

package ipsk.swing.action.tree;

import ipsk.util.LocalizableMessage;

import java.awt.ItemSelectable;
import java.awt.event.ActionEvent;

import javax.swing.Action;

/**
 * @author klausj
 *
 */
public abstract class CheckActionLeaf extends AbstractActionLeaf {

    /**
     * @param displayName display name
     */
    public CheckActionLeaf(LocalizableMessage displayName) {
        super(displayName);
        setSelected(true);
    }

    /* (non-Javadoc)
     * @see ips.incubator.awt.action.ActionLeaf#actionPerformed(java.awt.event.ActionEvent)
     */
    @Override
    public abstract void actionPerformed(ActionEvent arg0);

    public boolean isSelected() {
        Object selObj=getValue(Action.SELECTED_KEY);
        if(selObj!=null){
            if(selObj.equals(true)){
                return true;
            }
        }
        return false;
    }

    public void setSelected(boolean selected) {
        putValue(Action.SELECTED_KEY, selected);
    }

}
